@@ -49,19 +49,20 @@ def weights_size_kpi(mp_cfg: List[int],
     """
     weights_memory = []
     mp_nodes = graph.get_configurable_sorted_nodes_names()
+    weights_mp_nodes = [n.name for n in graph.get_sorted_weights_configurable_nodes()]
 
     if len(mp_cfg) == 0:
         # Computing non-configurable nodes KPI
         for n in graph.nodes:
-            if n.name not in mp_nodes and n.has_weights_quantization_enabled_candidate():
-                if len(n.candidates_quantization_cfg) == 1:
-                    node_nbits = n.candidates_quantization_cfg[0].weights_quantization_cfg.weights_n_bits
-                    node_weights_memory_in_bytes = _compute_node_weights_memory(n, node_nbits, fw_info)
-                    weights_memory.append(node_weights_memory_in_bytes)
-                elif not n.reuse:
-                    Logger.warning(f"Non-configurable nodes should have a single quantization configuration candidate,"
-                                   f"but node {n.name} has {len(n.candidates_quantization_cfg)} candidates. "
-                                   f"The node's weights memory is not considered for the weights KPI computation.")
+            non_configurable_node = n.name not in weights_mp_nodes \
+                                    and n.has_weights_quantization_enabled_candidate() \
+                                    and not n.reuse \
+                                    and n.is_all_weights_candidates_equal()
+
+            if non_configurable_node:
+                node_nbits = n.candidates_quantization_cfg[0].weights_quantization_cfg.weights_n_bits
+                node_weights_memory_in_bytes = _compute_node_weights_memory(n, node_nbits, fw_info)
+                weights_memory.append(node_weights_memory_in_bytes)
     else:
         # Go over configurable all nodes that should be taken into consideration when computing the weights KPI.
         for n in graph.get_sorted_weights_configurable_nodes():
@@ -98,19 +99,19 @@ def activation_output_size_kpi(mp_cfg: List[int],
     """
     activation_memory = []
     mp_nodes = graph.get_configurable_sorted_nodes_names()
+    activation_mp_nodes = [n.name for n in graph.get_sorted_activation_configurable_nodes()]
 
     if len(mp_cfg) == 0:
         # Computing non-configurable nodes KPI
         for n in graph.nodes:
-            if n.name not in mp_nodes and n.has_activation_quantization_enabled_candidate():
-                if len(n.candidates_quantization_cfg) == 1:
-                    node_nbits = n.candidates_quantization_cfg[0].activation_quantization_cfg.activation_n_bits
-                    node_activation_memory_in_bytes = _compute_node_activation_memory(n, node_nbits)
-                    activation_memory.append(node_activation_memory_in_bytes)
-                else:
-                    Logger.warning(f"Non-configurable nodes should have a single quantization configuration candidate,"
-                                   f"but node {n.name} has {len(n.candidates_quantization_cfg)} candidates. "
-                                   f"The node's activation memory is not considered for the weights KPI computation.")
+            non_configurable_node = n.name not in activation_mp_nodes \
+                                    and n.has_activation_quantization_enabled_candidate() \
+                                    and n.is_all_activation_candidates_equal()
+
+            if non_configurable_node:
+                node_nbits = n.candidates_quantization_cfg[0].activation_quantization_cfg.activation_n_bits
+                node_activation_memory_in_bytes = _compute_node_activation_memory(n, node_nbits)
+                activation_memory.append(node_activation_memory_in_bytes)
     else:
         # Go over all nodes that should be taken into consideration when computing the weights KPI.
         for n in graph.get_sorted_activation_configurable_nodes():
@@ -146,29 +147,40 @@ def total_weights_activation_kpi(mp_cfg: List[int],
 
     """
     weights_activation_memory = []
-    mp_nodes = graph.get_configurable_sorted_nodes_names()
+    weights_mp_nodes = [n.name for n in graph.get_sorted_weights_configurable_nodes()]
+    activation_mp_nodes = [n.name for n in graph.get_sorted_activation_configurable_nodes()]
 
     if len(mp_cfg) == 0:
         # Computing non-configurable nodes KPI
         for n in graph.nodes:
-            if n.name not in mp_nodes:
-                if len(n.candidates_quantization_cfg) == 1:
-                    node_weights_memory_in_bytes = 0
-                    if n.has_weights_quantization_enabled_candidate():
-                        node_weights_nbits = n.candidates_quantization_cfg[0].weights_quantization_cfg.weights_n_bits
-                        node_weights_memory_in_bytes = _compute_node_weights_memory(n, node_weights_nbits, fw_info)
 
-                    node_activation_memory_in_bytes = 0
-                    if n.has_activation_quantization_enabled_candidate():
-                        node_activation_nbits = n.candidates_quantization_cfg[0].activation_quantization_cfg.activation_n_bits
-                        node_activation_memory_in_bytes = _compute_node_activation_memory(n, node_activation_nbits)
+            non_configurable = False
+            node_weights_memory_in_bytes, node_activation_memory_in_bytes = 0, 0
 
-                    weights_activation_memory.append(
-                        np.array([node_weights_memory_in_bytes, node_activation_memory_in_bytes]))
-                elif not n.reuse:
-                    Logger.warning(f"Non-configurable nodes should have a single quantization configuration candidate,"
-                                   f"but node {n.name} has {len(n.candidates_quantization_cfg)} candidates. "
-                                   f"The node's activation memory is not considered for the weights KPI computation.")
+            # Non-configurable Weights
+            is_non_configurable_weights = n.name not in weights_mp_nodes and \
+                                          n.has_weights_quantization_enabled_candidate() and \
+                                          n.is_all_weights_candidates_equal() and \
+                                          not n.reuse
+
+            if is_non_configurable_weights:
+                node_nbits = n.candidates_quantization_cfg[0].weights_quantization_cfg.weights_n_bits
+                node_weights_memory_in_bytes = _compute_node_weights_memory(n, node_nbits, fw_info)
+                non_configurable = True
+
+            # Non-configurable Activation
+            is_non_configurable_activation = n.name not in activation_mp_nodes and \
+                                             n.has_activation_quantization_enabled_candidate() and \
+                                             n.is_all_activation_candidates_equal()
+
+            if is_non_configurable_activation:
+                node_nbits = n.candidates_quantization_cfg[0].activation_quantization_cfg.activation_n_bits
+                node_activation_memory_in_bytes = _compute_node_activation_memory(n, node_nbits)
+                non_configurable = True
+
+            if non_configurable:
+                weights_activation_memory.append(
+                    np.array([node_weights_memory_in_bytes, node_activation_memory_in_bytes]))
     else:
         # Go over all nodes that should be taken into consideration when computing the weights or
         # activation KPI (all configurable nodes).
@@ -220,15 +232,13 @@ def bops_kpi(mp_cfg: List[int],
                          fw_info,
                          fw_impl)
 
-    if len(mp_cfg) == 0:
-        # BOPs KPI method considers non-configurable nodes, therefore, it doesn't need separate implementation
-        # for non-configurable nodes only.
-        bops = []
-    else:
-        virtual_bops_nodes = [n for n in graph.get_topo_sorted_nodes() if isinstance(n, VirtualActivationWeightsNode)]
+    # BOPs KPI method considers non-configurable nodes, therefore, it doesn't need separate implementation
+    # for non-configurable nodes for setting a constraint (no need for separate implementation for len(mp_cfg) = 0).
 
-        mp_nodes = graph.get_configurable_sorted_nodes_names()
-        bops = [n.get_bops_count(fw_impl, fw_info, candidate_idx=_get_node_cfg_idx(n, mp_cfg, mp_nodes)) for n in virtual_bops_nodes]
+    virtual_bops_nodes = [n for n in graph.get_topo_sorted_nodes() if isinstance(n, VirtualActivationWeightsNode)]
+
+    mp_nodes = graph.get_configurable_sorted_nodes_names()
+    bops = [n.get_bops_count(fw_impl, fw_info, candidate_idx=_get_node_cfg_idx(n, mp_cfg, mp_nodes)) for n in virtual_bops_nodes]
 
     return np.array(bops)
 
@@ -260,7 +270,7 @@ def _bops_kpi(mp_cfg: List[int],
             # If node doesn't have weights then its MAC count is 0, and we shouldn't consider it in the BOPS count.
             incoming_edges = graph.incoming_edges(n, sort_by_attr=EDGE_SINK_INDEX)
             if len(incoming_edges) != 1:
-                Logger.critical(f"Can't compute BOPS metric for node {n.name} with multiple inputs.")
+                Logger.critical(f"Can't compute BOPS metric for node {n.name} with multiple inputs.")  # pragma: no cover
 
             input_activation_node = incoming_edges[0].source_node
             if len(graph.out_edges(input_activation_node)) > 1:
