@@ -141,7 +141,7 @@ class SensitivityEvaluation:
                                         node_idx)
 
         # Compute the distance matrix
-        distance_matrix = self._build_distance_metrix()
+        distance_matrix = self._build_distance_matrix()
 
         # Configure MP model back to the same configuration as the baseline model if baseline provided
         if baseline_mp_configuration is not None:
@@ -157,7 +157,8 @@ class SensitivityEvaluation:
         Evaluates the baseline model on all images and saves the obtained lists of tensors in a list for later use.
         Initiates a class variable self.baseline_tensors_list
         """
-        self.baseline_tensors_list = [self._tensors_as_list(self.fw_impl.to_numpy(self.baseline_model(images)))
+        self.baseline_tensors_list = [self.fw_impl.to_numpy(self.fw_impl.sensitivity_eval_inference(self.baseline_model,
+                                                                                                    images))
                                       for images in self.images_batches]
 
     def _build_models(self) -> Any:
@@ -200,6 +201,7 @@ class SensitivityEvaluation:
         for images in self.images_batches:
             batch_ip_gradients = []
             for i in range(1, images[0].shape[0] + 1):
+                Logger.info(f"Computing Jacobian-based weights approximation for image sample {i} out of {images[0].shape[0]}...")
                 image_ip_gradients = self.fw_impl.model_grad(self.graph,
                                                              {inode: images[0][i - 1:i] for inode in
                                                               self.graph.get_inputs()},
@@ -241,7 +243,7 @@ class SensitivityEvaluation:
                     current_layer = self.fw_impl.get_model_layer_by_name(model_mp, node_name)
                     self.set_layer_to_bitwidth(current_layer, mp_model_configuration[node_idx_to_configure])
                 else:
-                    raise Exception("The last configurable node is not included in the list of interest points for"
+                    raise Exception("The last configurable node is not included in the list of interest points for"  # pragma: no cover
                                     "sensitivity evaluation metric for the mixed-precision search.")
 
         else:  # use the entire mp_model_configuration to configure the model
@@ -252,7 +254,7 @@ class SensitivityEvaluation:
                     self.set_layer_to_bitwidth(current_layer, mp_model_configuration[node_idx_to_configure])
                 else:
                     raise Exception("The last configurable node is not included in the list of interest points for"
-                                    "sensitivity evaluation metric for the mixed-precision search.")
+                                    "sensitivity evaluation metric for the mixed-precision search.")  # pragma: no cover
 
     def _compute_distance_matrix(self,
                                  baseline_tensors: List[Any],
@@ -283,7 +285,7 @@ class SensitivityEvaluation:
 
         return distance_matrix
 
-    def _build_distance_metrix(self):
+    def _build_distance_matrix(self):
         """
         Builds a matrix that contains the distances between the baseline and MP models for each interest point.
         Returns: A distance matrix.
@@ -295,8 +297,8 @@ class SensitivityEvaluation:
         # Compute the distance matrix for num_of_images images.
         for images, baseline_tensors in zip(self.images_batches, self.baseline_tensors_list):
             # when using model.predict(), it does not use the QuantizeWrapper functionality
-            mp_tensors = self.model_mp(images)
-            mp_tensors = self._tensors_as_list(self.fw_impl.to_numpy(mp_tensors))
+            mp_tensors = self.fw_impl.sensitivity_eval_inference(self.model_mp, images)
+            mp_tensors = self.fw_impl.to_numpy(mp_tensors)
 
             # Build distance matrix: similarity between the baseline model to the float model
             # in every interest point for every image in the batch.
@@ -305,8 +307,6 @@ class SensitivityEvaluation:
         # Merge all distance matrices into a single distance matrix.
         distance_matrix = np.concatenate(distance_matrices, axis=1)
 
-        # Assert we used a correct number of images for computing the distance matrix
-        assert distance_matrix.shape[1] == self.quant_config.num_of_images
         return distance_matrix
 
     @staticmethod
@@ -339,9 +339,9 @@ class SensitivityEvaluation:
         # First, select images to use for all measurements.
         samples_count = 0  # Number of images we used so far to compute the distance matrix.
         images_batches = []
-        while samples_count < num_of_images:
-            # Get a batch of images to infer in both models.
-            inference_batch_input = self.representative_data_gen()
+        for inference_batch_input in self.representative_data_gen():
+            if samples_count >= num_of_images:
+                break
             batch_size = inference_batch_input[0].shape[0]
 
             # If we sampled more images than we should use in the distance matrix,
@@ -353,6 +353,10 @@ class SensitivityEvaluation:
 
             images_batches.append(inference_batch_input)
             samples_count += batch_size
+        else:
+            if samples_count < num_of_images:
+                Logger.warning(f'Not enough images in representative dataset to generate {num_of_images} data points, '
+                               f'only {samples_count} were generated')
         return images_batches
 
     def _update_ips_with_outputs_replacements(self):
@@ -379,21 +383,6 @@ class SensitivityEvaluation:
         replacement_indices = [self.interest_points.index(n) for n in self.outputs_replacement_nodes]
         return list(set(output_indices + replacement_indices))
 
-    @staticmethod
-    def _tensors_as_list(tensors: Any) -> List[Any]:
-        """
-        Create a list of tensors if they are not in a list already.
-        This functions helpful when the graph has only one node (so the model's output is a Tensor and not a list of
-        Tensors).
-        Args:
-            tensors: Tensors to return as a list.
-        Returns:
-            List of tensors.
-        """
-        if not isinstance(tensors, list):
-            return [tensors]
-        return tensors
-
 
 def get_mp_interest_points(graph: Graph,
                            interest_points_classifier: Callable,
