@@ -13,14 +13,12 @@
 # limitations under the License.
 # ==============================================================================
 
-import copy
-
 from typing import List
 
 from model_compression_toolkit.core import common
 
 
-def substitute(graph_to_substitute: common.Graph,
+def substitute(graph: common.Graph,
                substitutions_list: List[common.BaseSubstitution]) -> common.Graph:
     """
     Apply a list of substitutions on a graph.
@@ -32,9 +30,8 @@ def substitute(graph_to_substitute: common.Graph,
         Transformed graph after applying all substitutions in substitutions_list.
     """
 
-    graph = copy.deepcopy(graph_to_substitute)
     for substitution in substitutions_list:
         matched_nodes = graph.filter(substitution.matcher_instance)
         for idn in matched_nodes:
             graph = substitution.substitute(graph, idn)
-    return graph
\ No newline at end of file
+    return graph
