@@ -74,8 +74,6 @@ from model_compression_toolkit.core.keras.graph_substitutions.substitutions.remo
     RemoveReLUUpperBound
 from model_compression_toolkit.core.keras.graph_substitutions.substitutions.multi_head_attention_decomposition import \
     MultiHeadAttentionDecomposition
-from model_compression_toolkit.core.keras.graph_substitutions.substitutions.layer_norm_decomposition import \
-    LayerNormDecomposition
 from model_compression_toolkit.core.keras.graph_substitutions.substitutions.scale_equalization import \
     ScaleEqualization, ScaleEqualizationWithPad, ScaleEqualizationMidActivation, ScaleEqualizationMidActivationWithPad
 from model_compression_toolkit.core.keras.graph_substitutions.substitutions.separableconv_decomposition import \
@@ -242,14 +240,13 @@ class KerasImplementation(FrameworkImplementation):
                                        ScaleEqualizationMidActivationWithPad(quant_config, fw_info)])
         return substitutions_list
 
-    def get_substitutions_prepare_graph(self) -> List[common.BaseSubstitution]:
+    def get_substitutions_prepare_graph(self, fw_info: FrameworkInfo = None) -> List[common.BaseSubstitution]:
         """
 
         Returns: A list of the framework substitutions used to prepare the graph.
 
         """
         return [SeparableConvDecomposition(),
-                LayerNormDecomposition(),
                 MultiHeadAttentionDecomposition(),
                 ActivationDecomposition()]
 
@@ -445,10 +442,14 @@ class KerasImplementation(FrameworkImplementation):
 
         if layer_class == Activation:
             node_type_name = framework_attrs[ACTIVATION]
-            if node_type_name == SOFTMAX or node_type_name == SIGMOID:
+            if node_type_name == SOFTMAX:
                 return compute_kl_divergence
-        elif layer_class == tf.nn.softmax or layer_class == tf.nn.sigmoid:
+            elif node_type_name == SIGMOID:
+                return compute_cs
+        elif layer_class == tf.nn.softmax:
             return compute_kl_divergence
+        elif layer_class == tf.nn.sigmoid:
+            return compute_cs
         elif layer_class == Dense:
             return compute_cs
         return compute_mse
@@ -532,7 +533,7 @@ class KerasImplementation(FrameworkImplementation):
 
         if node.layer_class == TFOpLambda:
             node_attr = getattr(node, 'framework_attr', None)
-            if node_attr is not None and ARGMAX in node_attr[LAYER_NAME]:
+            if node_attr is not None and (ARGMAX in node_attr[LAYER_NAME] or SOFTMAX in node_attr[LAYER_NAME]):
                 return False
         elif node.layer_class == tf.nn.softmax or node.layer_class == tf.math.argmax:
             return False
@@ -594,3 +595,19 @@ class KerasImplementation(FrameworkImplementation):
         graph_after_second_moment_correction = keras_apply_second_moment_correction(quantized_model, core_config,
                                                                                     representative_data_gen, graph)
         return graph_after_second_moment_correction
+
+    def sensitivity_eval_inference(self,
+                                   model: Model,
+                                   inputs: Any):
+        """
+        Calls for a Keras model inference for a specific framework during mixed precision sensitivity evaluation.
+
+        Args:
+            model: A Keras model to run inference for.
+            inputs: Input tensors to run inference on.
+
+        Returns:
+            The output of the model inference on the given input.
+        """
+
+        return model(inputs)
