@@ -19,7 +19,7 @@ from model_compression_toolkit.core import common
 from model_compression_toolkit.core.common import Logger
 from model_compression_toolkit.core.common.constants import TENSORFLOW
 from model_compression_toolkit.core.common.user_info import UserInformation
-from model_compression_toolkit.gptq.common.gptq_config import GradientPTQConfig
+from model_compression_toolkit.gptq import GradientPTQConfig, GradientPTQConfigV2
 from model_compression_toolkit.core.common.mixed_precision.kpi_tools.kpi import KPI
 from model_compression_toolkit.core.common.framework_info import FrameworkInfo
 from model_compression_toolkit.core.common.network_editors.actions import EditRule
@@ -35,13 +35,10 @@ from model_compression_toolkit.ptq.runner import ptq_runner
 from model_compression_toolkit.core.exporter import export_model
 from model_compression_toolkit.core.analyzer import analyzer_model_quantization
 
-import importlib
+from model_compression_toolkit.target_platform_capabilities.target_platform.targetplatform2framework import TargetPlatformCapabilities
+from model_compression_toolkit.core.common.constants import FOUND_TF
 
-from model_compression_toolkit.core.common.target_platform.targetplatform2framework import TargetPlatformCapabilities
-
-
-if importlib.util.find_spec("tensorflow") is not None\
-        and importlib.util.find_spec("tensorflow_model_optimization") is not None:
+if FOUND_TF:
     from model_compression_toolkit.core.keras.default_framework_info import DEFAULT_KERAS_INFO
     from model_compression_toolkit.core.keras.keras_implementation import KerasImplementation
     from model_compression_toolkit.core.keras.keras_model_validation import KerasModelValidation
@@ -49,6 +46,7 @@ if importlib.util.find_spec("tensorflow") is not None\
     from model_compression_toolkit.core.keras.constants import DEFAULT_TP_MODEL
 
     from model_compression_toolkit import get_target_platform_capabilities
+
     DEFAULT_KERAS_TPC = get_target_platform_capabilities(TENSORFLOW, DEFAULT_TP_MODEL)
 
 
@@ -60,7 +58,8 @@ if importlib.util.find_spec("tensorflow") is not None\
                                          network_editor: List[EditRule] = [],
                                          gptq_config: GradientPTQConfig = None,
                                          analyze_similarity: bool = False,
-                                         target_platform_capabilities: TargetPlatformCapabilities = DEFAULT_KERAS_TPC) -> Tuple[Model, UserInformation]:
+                                         target_platform_capabilities: TargetPlatformCapabilities = DEFAULT_KERAS_TPC) -> \
+    Tuple[Model, UserInformation]:
         """
         Quantize a pretrained Keras model using post-training quantization. By default, the model is quantized
         using a symmetric constraint quantization thresholds (power of two) as defined in the default TargetPlatformCapabilities.
@@ -82,7 +81,7 @@ if importlib.util.find_spec("tensorflow") is not None\
             network_editor (List[EditRule]): List of EditRules. Each EditRule consists of a node filter and an action to change quantization settings of the filtered nodes.
             gptq_config (GradientPTQConfig): Configuration for using gptq (e.g. optimizer).
             analyze_similarity (bool): Whether to plot similarity figures within TensorBoard (when logger is enabled) or not.
-            target_platform_capabilities (TargetPlatformCapabilities): TargetPlatformCapabilities to optimize the Keras model according to. `Default Keras TPC <https://github.com/sony/model_optimization/blob/main/model_compression_toolkit/core/tpc_models/keras_tp_models/keras_default.py>`_
+            target_platform_capabilities (TargetPlatformCapabilities): TargetPlatformCapabilities to optimize the Keras model according to.
 
         Returns:
             A quantized model and information the user may need to handle the quantized model.
@@ -108,8 +107,7 @@ if importlib.util.find_spec("tensorflow") is not None\
         KerasModelValidation(model=in_model,
                              fw_info=fw_info).validate()
 
-        core_config = CoreConfig(n_iter,
-                                 quantization_config=quant_config,
+        core_config = CoreConfig(quantization_config=quant_config,
                                  debug_config=DebugConfig(analyze_similarity=analyze_similarity,
                                                           network_editor=network_editor)
                                  )
@@ -118,8 +116,13 @@ if importlib.util.find_spec("tensorflow") is not None\
 
         fw_impl = KerasImplementation()
 
+        # convert old representative dataset generation to a generator
+        def _representative_data_gen():
+            for _ in range(n_iter):
+                yield representative_data_gen()
+
         tg, bit_widths_config = core_runner(in_model=in_model,
-                                            representative_data_gen=representative_data_gen,
+                                            representative_data_gen=_representative_data_gen,
                                             core_config=core_config,
                                             fw_info=fw_info,
                                             fw_impl=fw_impl,
@@ -127,13 +130,14 @@ if importlib.util.find_spec("tensorflow") is not None\
                                             tb_w=tb_w)
 
         if gptq_config is None:
-            tg = ptq_runner(tg, representative_data_gen, core_config, fw_info, fw_impl, tb_w)
+            tg = ptq_runner(tg, _representative_data_gen, core_config, fw_info, fw_impl, tb_w)
         else:
-            tg = gptq_runner(tg, core_config, gptq_config, representative_data_gen,
+            gptq_config_v2 = GradientPTQConfigV2.from_v1(n_iter, gptq_config)
+            tg = gptq_runner(tg, core_config, gptq_config_v2, _representative_data_gen, _representative_data_gen,
                              fw_info, fw_impl, tb_w)
 
         if core_config.debug_config.analyze_similarity:
-            analyzer_model_quantization(representative_data_gen, tb_w, tg, fw_impl, fw_info)
+            analyzer_model_quantization(_representative_data_gen, tb_w, tg, fw_impl, fw_info)
 
         quantized_model, user_info = export_model(tg, fw_info, fw_impl, tb_w, bit_widths_config)
 
@@ -149,7 +153,8 @@ if importlib.util.find_spec("tensorflow") is not None\
                                                          network_editor: List[EditRule] = [],
                                                          gptq_config: GradientPTQConfig = None,
                                                          analyze_similarity: bool = False,
-                                                         target_platform_capabilities: TargetPlatformCapabilities = DEFAULT_KERAS_TPC) -> Tuple[Model, UserInformation]:
+                                                         target_platform_capabilities: TargetPlatformCapabilities = DEFAULT_KERAS_TPC) -> \
+    Tuple[Model, UserInformation]:
         """
          Quantize a pretrained Keras model using post-training quantization. By default, the model is quantized
          using a symmetric constraint quantization thresholds (power of two) as defined in the default
@@ -179,7 +184,7 @@ if importlib.util.find_spec("tensorflow") is not None\
              network_editor (List[EditRule]): List of EditRules. Each EditRule consists of a node filter and an action to change quantization settings of the filtered nodes.
              gptq_config (GradientPTQConfig): Configuration for using GPTQ (e.g. optimizer).
              analyze_similarity (bool): Whether to plot similarity figures within TensorBoard (when logger is enabled) or not.
-             target_platform_capabilities (TargetPlatformCapabilities): TargetPlatformCapabilities to optimize the Keras model according to. `Default Keras TPC <https://github.com/sony/model_optimization/blob/main/model_compression_toolkit/core/tpc_models/keras_tp_models/keras_default.py>`_
+             target_platform_capabilities (TargetPlatformCapabilities): TargetPlatformCapabilities to optimize the Keras model according to.
 
 
          Returns:
@@ -232,8 +237,7 @@ if importlib.util.find_spec("tensorflow") is not None\
                            "If you encounter an issue please file a bug.")
 
         quantization_config, mp_config = quant_config.separate_configs()
-        core_config = CoreConfig(n_iter,
-                                 quantization_config=quantization_config,
+        core_config = CoreConfig(quantization_config=quantization_config,
                                  mixed_precision_config=mp_config,
                                  debug_config=DebugConfig(analyze_similarity=analyze_similarity,
                                                           network_editor=network_editor)
@@ -243,8 +247,13 @@ if importlib.util.find_spec("tensorflow") is not None\
 
         fw_impl = KerasImplementation()
 
+        # convert old representative dataset generation to a generator
+        def _representative_data_gen():
+            for _ in range(n_iter):
+                yield representative_data_gen()
+
         tg, bit_widths_config = core_runner(in_model=in_model,
-                                            representative_data_gen=representative_data_gen,
+                                            representative_data_gen=_representative_data_gen,
                                             core_config=core_config,
                                             fw_info=fw_info,
                                             fw_impl=fw_impl,
@@ -253,13 +262,14 @@ if importlib.util.find_spec("tensorflow") is not None\
                                             tb_w=tb_w)
 
         if gptq_config is None:
-            tg = ptq_runner(tg, representative_data_gen, core_config, fw_info, fw_impl, tb_w)
+            tg = ptq_runner(tg, _representative_data_gen, core_config, fw_info, fw_impl, tb_w)
         else:
-            tg = gptq_runner(tg, core_config, gptq_config, representative_data_gen,
+            gptq_config_v2 = GradientPTQConfigV2.from_v1(n_iter, gptq_config)
+            tg = gptq_runner(tg, core_config, gptq_config_v2, _representative_data_gen, _representative_data_gen,
                              fw_info, fw_impl, tb_w)
 
         if core_config.debug_config.analyze_similarity:
-            analyzer_model_quantization(representative_data_gen, tb_w, tg, fw_impl, fw_info)
+            analyzer_model_quantization(_representative_data_gen, tb_w, tg, fw_impl, fw_info)
 
         quantized_model, user_info = export_model(tg, fw_info, fw_impl, tb_w, bit_widths_config)
 
@@ -271,9 +281,10 @@ else:
     def keras_post_training_quantization(*args, **kwargs):
         Logger.critical('Installing tensorflow and tensorflow_model_optimization is mandatory '
                         'when using keras_post_training_quantization. '
-                        'Could not find Tensorflow package.')
+                        'Could not find Tensorflow package.')  # pragma: no cover
+
 
     def keras_post_training_quantization_mixed_precision(*args, **kwargs):
         Logger.critical('Installing tensorflow and tensorflow_model_optimization is mandatory '
                         'when using keras_post_training_quantization_mixed_precision. '
-                        'Could not find Tensorflow package.')
+                        'Could not find Tensorflow package.')  # pragma: no cover
