@@ -20,6 +20,7 @@ import torch.nn as nn
 import operator
 from typing import List
 
+from model_compression_toolkit.core.common.logger import Logger
 from model_compression_toolkit.core import common
 from model_compression_toolkit.core.common.graph.base_graph import Graph, BaseNode, OutTensor
 from model_compression_toolkit.core.common.graph.functional_node import FunctionalNode
@@ -46,32 +47,26 @@ class MHAParams:
         # Only batch first network is supported
         if BATCH_FIRST in mha_node.framework_attr.keys():
             if mha_node.framework_attr[BATCH_FIRST] is not True:
-                raise Exception('Only batch first network is supported')
+                Logger.error('Only batch first network is supported')  # pragma: no cover
         else:
-            raise Exception('Only batch first network is supported')
+            Logger.error('Only batch first network is supported')  # pragma: no cover
 
         # Add Zero Attn feature is Not Implemented
         if ADD_ZERO_ATTN in mha_node.framework_attr.keys():
             if mha_node.framework_attr[ADD_ZERO_ATTN] is not False:
-                raise Exception('Add Zero Attn feature is Not Implemented')
+                Logger.error('Add Zero Attn feature is Not Implemented')  # pragma: no cover
 
         # Check if Add Bias KV feature is Active
         if BIAS_K and BIAS_V in mha_node.weights.keys():
-            if mha_node.weights[BIAS_K] and mha_node.weights[BIAS_V] is not None:
-                raise Exception('Add BIAS_KV feature is Not Implemented')
+            if mha_node.weights[BIAS_K] is not None and mha_node.weights[BIAS_V] is not None:
+                Logger.error('Add BIAS_KV feature is Not Implemented')  # pragma: no cover
 
         self.embed_dim = mha_node.framework_attr[EMBED_DIM]
         self.num_heads = mha_node.framework_attr[NUM_HEADS]
 
-        if KEY_DIM in mha_node.framework_attr:
-            self.kdim = mha_node.framework_attr[KEY_DIM]
-        else:
-            self.kdim = False
+        self.kdim = mha_node.framework_attr[KEY_DIM]
 
-        if VALUE_DIM in mha_node.framework_attr:
-            self.vdim = mha_node.framework_attr[VALUE_DIM]
-        else:
-            self.vdim = False
+        self.vdim = mha_node.framework_attr[VALUE_DIM]
 
         self.qdim = int(self.embed_dim / self.num_heads)
 
@@ -707,7 +702,7 @@ class MultiHeadAttentionDecomposition(common.BaseSubstitution):
         """
 
         if mha_node.reuse:
-            raise Exception("MCT doesn't support reuse of MultiHeadAttention layer")
+            raise Exception("MCT doesn't support reuse of MultiHeadAttention layer")  # pragma: no cover
         params = MHAParams(mha_node)
 
         # project
