@@ -13,6 +13,7 @@
 # limitations under the License.
 # ==============================================================================
 import operator
+from copy import deepcopy
 from typing import List, Any, Tuple, Callable, Type, Dict
 
 import numpy as np
@@ -50,6 +51,8 @@ from model_compression_toolkit.core.pytorch.graph_substitutions.substitutions.mu
     import MultiHeadAttentionDecomposition
 from model_compression_toolkit.core.pytorch.graph_substitutions.substitutions.permute_call_method import \
     PermuteCallMethod
+from model_compression_toolkit.core.pytorch.graph_substitutions.substitutions.const_holder_conv import \
+    ConstantHolderConv
 from model_compression_toolkit.core.pytorch.graph_substitutions.substitutions.relu_bound_to_power_of_2 import \
     ReLUBoundToPowerOfTwo
 from model_compression_toolkit.core.pytorch.graph_substitutions.substitutions.reshape_with_static_shapes import \
@@ -72,8 +75,7 @@ from model_compression_toolkit.core.pytorch.pytorch_node_prior_info import creat
 from model_compression_toolkit.core.pytorch.reader.reader import model_reader
 from model_compression_toolkit.core.pytorch.statistics_correction.apply_second_moment_correction import \
     pytorch_apply_second_moment_correction
-from model_compression_toolkit.core.pytorch.utils import to_torch_tensor
-from model_compression_toolkit.core.pytorch.utils import torch_tensor_to_numpy
+from model_compression_toolkit.core.pytorch.utils import to_torch_tensor, torch_tensor_to_numpy, set_model
 from model_compression_toolkit.gptq.common.gptq_training import GPTQTrainer
 from model_compression_toolkit.gptq.pytorch.gptq_training import PytorchGPTQTrainer
 
@@ -125,7 +127,9 @@ class PytorchImplementation(FrameworkImplementation):
         Returns:
             Graph representing the input module.
         """
-        return model_reader(module, representative_data_gen, self.to_numpy, self.to_tensor)
+        _module = deepcopy(module)
+        _module.eval()
+        return model_reader(_module, representative_data_gen, self.to_numpy, self.to_tensor)
 
     def model_builder(self,
                       graph: Graph,
@@ -221,7 +225,7 @@ class PytorchImplementation(FrameworkImplementation):
                                        ScaleEqualizationWithPad(quant_config, fw_info)])
         return substitutions_list
 
-    def get_substitutions_prepare_graph(self) -> List[common.BaseSubstitution]:
+    def get_substitutions_prepare_graph(self, fw_info: FrameworkInfo = None) -> List[common.BaseSubstitution]:
         """
 
         Returns: A list of the framework substitutions used before we collect the prior information.
@@ -229,7 +233,8 @@ class PytorchImplementation(FrameworkImplementation):
         """
         return [ReshapeWithStaticShapes(),
                 MultiHeadAttentionDecomposition(),
-                PermuteCallMethod()]
+                PermuteCallMethod(),
+                ConstantHolderConv(fw_info)]
 
     def get_substitutions_pre_statistics_collection(self,
                                                     quant_config: QuantizationConfig
@@ -405,8 +410,10 @@ class PytorchImplementation(FrameworkImplementation):
         if compute_distance_fn is not None:
             return compute_distance_fn
 
-        elif layer_class in [Sigmoid, sigmoid, Softmax, softmax]:
+        elif layer_class in [Softmax, softmax]:
             return compute_kl_divergence
+        elif layer_class in [Sigmoid, sigmoid]:
+            return compute_cs
         elif layer_class == Linear:
             return compute_cs
         return compute_mse
@@ -487,7 +494,7 @@ class PytorchImplementation(FrameworkImplementation):
 
         """
 
-        return node.layer_class not in [argmax]
+        return node.layer_class not in [argmax, softmax]
 
     def get_node_mac_operations(self,
                                 node: BaseNode,
@@ -538,3 +545,20 @@ class PytorchImplementation(FrameworkImplementation):
         graph_after_second_moment_correction = pytorch_apply_second_moment_correction(quantized_model, core_config,
                                                                                       representative_data_gen, graph)
         return graph_after_second_moment_correction
+
+    def sensitivity_eval_inference(self,
+                                   model: Module,
+                                   inputs: Any):
+        """
+        Calls for a Pytorch model inference for a specific framework during mixed precision sensitivity evaluation.
+        In Pytorch, we need to unfold the list of inputs before passing it to the model.
+
+        Args:
+            model: A Pytorch model to run inference for.
+            inputs: Input tensors to run inference on.
+
+        Returns:
+            The output of the model inference on the given input.
+        """
+
+        return model(*inputs)
\ No newline at end of file
