@@ -18,8 +18,8 @@ from model_compression_toolkit.core import common
 from model_compression_toolkit.core.common import Logger
 from model_compression_toolkit.core.common.constants import PYTORCH
 from model_compression_toolkit.core.common.user_info import UserInformation
-from model_compression_toolkit.gptq.common.gptq_config import GradientPTQConfig
-from model_compression_toolkit.core.common.target_platform import TargetPlatformCapabilities
+from model_compression_toolkit.gptq.common.gptq_config import GradientPTQConfig, GradientPTQConfigV2
+from model_compression_toolkit.target_platform_capabilities.target_platform import TargetPlatformCapabilities
 from model_compression_toolkit.core.common.mixed_precision.kpi_tools.kpi import KPI
 from model_compression_toolkit.core.common.framework_info import FrameworkInfo
 from model_compression_toolkit.core.common.network_editors.actions import EditRule
@@ -34,10 +34,9 @@ from model_compression_toolkit.gptq.runner import gptq_runner
 from model_compression_toolkit.ptq.runner import ptq_runner
 from model_compression_toolkit.core.exporter import export_model
 from model_compression_toolkit.core.analyzer import analyzer_model_quantization
+from model_compression_toolkit.core.common.constants import FOUND_TORCH
 
-import importlib
-
-if importlib.util.find_spec("torch") is not None:
+if FOUND_TORCH:
     from model_compression_toolkit.core.pytorch.default_framework_info import DEFAULT_PYTORCH_INFO
     from model_compression_toolkit.core.pytorch.pytorch_implementation import PytorchImplementation
     from model_compression_toolkit.core.pytorch.constants import DEFAULT_TP_MODEL
@@ -77,7 +76,7 @@ if importlib.util.find_spec("torch") is not None:
             network_editor (List[EditRule]): List of EditRules. Each EditRule consists of a node filter and an action to change quantization settings of the filtered nodes.
             gptq_config (GradientPTQConfig): Configuration for using gptq (e.g. optimizer).
             analyze_similarity (bool): Whether to plot similarity figures within TensorBoard (when logger is enabled) or not.
-            target_platform_capabilities (TargetPlatformCapabilities): TargetPlatformCapabilities to optimize the PyTorch model according to. `Default PyTorch TPC <https://github.com/sony/model_optimization/blob/main/model_compression_toolkit/core/tpc_models/pytorch_tp_models/pytorch_default.py>`_
+            target_platform_capabilities (TargetPlatformCapabilities): TargetPlatformCapabilities to optimize the PyTorch model according to.
 
 
         Returns:
@@ -102,7 +101,7 @@ if importlib.util.find_spec("torch") is not None:
 
         """
 
-        core_config = CoreConfig(n_iter, quant_config,
+        core_config = CoreConfig(quant_config,
                                  debug_config=DebugConfig(analyze_similarity=analyze_similarity,
                                                           network_editor=network_editor))
 
@@ -110,8 +109,13 @@ if importlib.util.find_spec("torch") is not None:
 
         fw_impl = PytorchImplementation()
 
+        # convert old representative dataset generation to a generator
+        def _representative_data_gen():
+            for _ in range(n_iter):
+                yield representative_data_gen()
+
         tg, bit_widths_config = core_runner(in_model=in_module,
-                                            representative_data_gen=representative_data_gen,
+                                            representative_data_gen=_representative_data_gen,
                                             core_config=core_config,
                                             fw_info=fw_info,
                                             fw_impl=fw_impl,
@@ -119,13 +123,14 @@ if importlib.util.find_spec("torch") is not None:
                                             tb_w=tb_w)
 
         if gptq_config is None:
-            tg = ptq_runner(tg, representative_data_gen, core_config, fw_info, fw_impl, tb_w)
+            tg = ptq_runner(tg, _representative_data_gen, core_config, fw_info, fw_impl, tb_w)
         else:
-            tg = gptq_runner(tg, core_config, gptq_config, representative_data_gen,
+            gptq_config_v2 = GradientPTQConfigV2.from_v1(n_iter, gptq_config)
+            tg = gptq_runner(tg, core_config, gptq_config_v2, _representative_data_gen, _representative_data_gen,
                              fw_info, fw_impl, tb_w)
 
         if core_config.debug_config.analyze_similarity:
-            analyzer_model_quantization(representative_data_gen, tb_w, tg, fw_impl, fw_info)
+            analyzer_model_quantization(_representative_data_gen, tb_w, tg, fw_impl, fw_info)
 
         quantized_model, user_info = export_model(tg, fw_info, fw_impl, tb_w, bit_widths_config)
 
@@ -170,7 +175,7 @@ if importlib.util.find_spec("torch") is not None:
              network_editor (List[EditRule]): List of EditRules. Each EditRule consists of a node filter and an action to change quantization settings of the filtered nodes.
              gptq_config (GradientPTQConfig): Configuration for using GPTQ (e.g. optimizer).
              analyze_similarity (bool): Whether to plot similarity figures within TensorBoard (when logger is enabled) or not.
-             target_platform_capabilities (TargetPlatformCapabilities): TargetPlatformCapabilities to optimize the PyTorch model according to. `Default PyTorch TPC <https://github.com/sony/model_optimization/blob/main/model_compression_toolkit/core/tpc_models/pytorch_tp_models/pytorch_default.py>`_
+             target_platform_capabilities (TargetPlatformCapabilities): TargetPlatformCapabilities to optimize the PyTorch model according to.
 
          Returns:
              A quantized model and information the user may need to handle the quantized model.
@@ -220,8 +225,7 @@ if importlib.util.find_spec("torch") is not None:
                            "If you encounter an issue please file a bug.")
 
         quantization_config, mp_config = quant_config.separate_configs()
-        core_config = CoreConfig(n_iter,
-                                 quantization_config=quantization_config,
+        core_config = CoreConfig(quantization_config=quantization_config,
                                  mixed_precision_config=mp_config,
                                  debug_config=DebugConfig(analyze_similarity=analyze_similarity,
                                                           network_editor=network_editor))
@@ -230,8 +234,13 @@ if importlib.util.find_spec("torch") is not None:
 
         fw_impl = PytorchImplementation()
 
+        # convert old representative dataset generation to a generator
+        def _representative_data_gen():
+            for _ in range(n_iter):
+                yield representative_data_gen()
+
         tg, bit_widths_config = core_runner(in_model=in_model,
-                                            representative_data_gen=representative_data_gen,
+                                            representative_data_gen=_representative_data_gen,
                                             core_config=core_config,
                                             fw_info=fw_info,
                                             fw_impl=fw_impl,
@@ -240,13 +249,14 @@ if importlib.util.find_spec("torch") is not None:
                                             tb_w=tb_w)
 
         if gptq_config is None:
-            tg = ptq_runner(tg, representative_data_gen, core_config, fw_info, fw_impl, tb_w)
+            tg = ptq_runner(tg, _representative_data_gen, core_config, fw_info, fw_impl, tb_w)
         else:
-            tg = gptq_runner(tg, core_config, gptq_config, representative_data_gen,
+            gptq_config_v2 = GradientPTQConfigV2.from_v1(n_iter, gptq_config)
+            tg = gptq_runner(tg, core_config, gptq_config_v2, _representative_data_gen, _representative_data_gen,
                              fw_info, fw_impl, tb_w)
 
         if core_config.debug_config.analyze_similarity:
-            analyzer_model_quantization(representative_data_gen, tb_w, tg, fw_impl, fw_info)
+            analyzer_model_quantization(_representative_data_gen, tb_w, tg, fw_impl, fw_info)
 
         quantized_model, user_info = export_model(tg, fw_info, fw_impl, tb_w, bit_widths_config)
 
@@ -259,9 +269,9 @@ else:
     def pytorch_post_training_quantization(*args, **kwargs):
         Logger.critical('Installing Pytorch is mandatory '
                         'when using pytorch_post_training_quantization. '
-                        'Could not find the torch package.')
+                        'Could not find the torch package.')  # pragma: no cover
 
     def pytorch_post_training_quantization_mixed_precision(*args, **kwargs):
         Logger.critical('Installing tensorflow and tensorflow_model_optimization is mandatory '
                         'when using pytorch_post_training_quantization_mixed_precision. '
-                        'Could not find Tensorflow package.')
+                        'Could not find Tensorflow package.')  # pragma: no cover
