@@ -48,7 +48,7 @@ from model_compression_toolkit.core.common.statistics_correction.statistics_corr
 from model_compression_toolkit.core.common.substitutions.apply_substitutions import substitute
 from model_compression_toolkit.core.common.substitutions.linear_collapsing_substitution import \
     linear_collapsing_substitute
-from model_compression_toolkit.core.common.target_platform.targetplatform2framework import TargetPlatformCapabilities
+from model_compression_toolkit.target_platform_capabilities.target_platform.targetplatform2framework import TargetPlatformCapabilities
 from model_compression_toolkit.core.common.visualization.final_config_visualizer import \
     WeightsFinalBitwidthConfigVisualizer, \
     ActivationFinalBitwidthConfigVisualizer
@@ -190,7 +190,7 @@ def get_finalized_graph(initial_graph: Graph,
     ######################################
     # Graph substitution (prepare graph)
     ######################################
-    graph = substitute(initial_graph, fw_impl.get_substitutions_prepare_graph())
+    graph = substitute(initial_graph, fw_impl.get_substitutions_prepare_graph(fw_info))
 
     if tb_w is not None:
         tb_w.add_graph(graph, 'after_graph_preparation')
@@ -348,8 +348,8 @@ def _prepare_model_for_quantization(graph: Graph,
                         fw_impl,
                         fw_info)
 
-    for _ in tqdm(range(core_config.n_iter)):
-        mi.infer(representative_data_gen())
+    for _data in tqdm(representative_data_gen()):
+        mi.infer(_data)
 
     ######################################
     # Edit network according to user
@@ -433,10 +433,17 @@ def _set_final_kpi(graph: Graph,
                 final_kpis_dict[kpi_target] = kpi_aggr(np.concatenate([conf_kpi, non_conf_kpi]), False)[0]
             elif len(final_bit_widths_config) > 0 and len(non_conf_kpi) == 0:
                 final_kpis_dict[kpi_target] = kpi_aggr(conf_kpi, False)[0]
-            else:
+            elif len(final_bit_widths_config) == 0 and len(non_conf_kpi) > 0:
                 # final_bit_widths_config == 0 ==> no configurable nodes,
                 # thus, KPI can be computed from non_conf_kpi alone
                 final_kpis_dict[kpi_target] = kpi_aggr(non_conf_kpi, False)[0]
+            else:
+                # No relevant nodes have been quantized with affect on the given target - since we only consider
+                # in the model's final size the quantized layers size, this means that the final size for this target
+                # is zero.
+                Logger.warning(f"No relevant quantized layers for the KPI target {kpi_target} were found, the recorded"
+                               f"final KPI for this target would be 0.")
+                final_kpis_dict[kpi_target] = 0
 
     final_kpi = KPI()
     final_kpi.set_kpi_by_target(final_kpis_dict)
