@@ -13,8 +13,7 @@
 # limitations under the License.
 # ==============================================================================
 
-from model_compression_toolkit.core.common.constants import FOUND_TF
+from model_compression_toolkit.exporter.model_exporter.keras.keras_export_facade import keras_export_model, KerasExportMode
+from model_compression_toolkit.exporter.model_exporter.pytorch.pytorch_export_facade import PyTorchExportMode, pytorch_export_model
+from model_compression_toolkit.exporter.model_exporter.tflite.tflite_export_facade import tflite_export_model, TFLiteExportMode
 
-if FOUND_TF:
-    from model_compression_toolkit.exporter.fully_quantized.keras.builder.fully_quantized_model_builder import \
-        get_fully_quantized_keras_model
\ No newline at end of file
